@@ -4,6 +4,16 @@ from os import listdir
 
 class Paperset:
     def __init__(self, directory: str) -> None:
+        """
+        The Paperset class:
+            __init__ args:
+                directory: a string, the directory where the jsons are stored
+
+            description:
+                lazy loader for cord-19 text files. Data is not actually loaded
+                until indexing, until then it just indexes files. Can be
+                indexed with both ints and slices.
+        """
         self.directory = directory
         self.dir_dict = {idx: f for idx, f in enumerate(listdir(self.directory))}
 
